@@ -178,7 +178,9 @@ class Labeler(QMainWindow):
 
     def __init__(self):
         super().__init__()
-        uic.loadUi("./resilipy/ui/labeler.ui", self)
+        dirname = os.path.dirname(__file__)
+        ui = os.path.join(dirname, "../ui/labeler.ui")
+        uic.loadUi(ui, self)
 
         self.threadpool = QThreadPool()
 
@@ -212,7 +214,9 @@ class Labeler(QMainWindow):
         """
         Reads and sets up the stylesheet.
         """
-        with open("./resilipy/ui/stylesheet.txt") as file:
+        dirname = os.path.dirname(__file__)
+        path = os.path.join(dirname, "../ui/stylesheet.txt")
+        with open(path) as file:
             stylesheet = file.read()
             self.setStyleSheet(stylesheet)
 
@@ -221,7 +225,10 @@ class Labeler(QMainWindow):
         Add one radio button for each model file that is placed in the "models" folder
         """
         # get all .model files that are given in the Models folder
-        path = os.path.relpath("./resilipy/models")
+        dirname = os.path.dirname(__file__)
+        path = os.path.join(dirname, "../models")
+
+        #path = os.path.relpath("./resilipy/models")
         file_names = os.listdir(path)
 
         if len(file_names) > 0:
